Requirements — Bloxone API Wrapper 0.5.7 documentation

# Requirements

Important

`bloxone` requires Python 3.x and was developed under Python 3.8. As such it is unlikely to work with Python 2.x.

## Additional Modules

In addition to the standard Python 3 Modules `bloxone` makes use of the following packages:

> - `requests`

## Complete List Of Modules

Modules used by bloxone

    import logging
    import configparser
    import requests
    import json
    import datetime